@@ -6,50 +6,70 @@ import time
 from cmd import Cmd
 from optparse import OptionParser
 
-from connect import StompConnection10,StompConnection11,StompConnection12
-from listener import ConnectionListener, StatsListener
-from exception import NotConnectedException
-from backward import input_prompt
-import colors
+from stomp.connect import StompConnection10,StompConnection11,StompConnection12
+from stomp.listener import ConnectionListener, StatsListener
+from stomp.adapter.multicast import MulticastConnection
+import stomp.colors
 sys.path.append('.')
 import stomp
 
+
+##@namespace stomp.__main__
+# The stomp.py command line client (used for testing or simple STOMP command scripting).
+
+##
+# Command-line version string
+#
 stomppy_version = 'Stomp.py Version %s.%s.%s' % stomp.__version__
 
 try:
-    import uuid    
+    import uuid
 except ImportError:
     from backward import uuid
 
+
 class SubscriptionInfo:
+    """
+    Used to store info about a subscription.
+    """
     def __init__(self, id, ack):
         self.id = id
         self.ack = ack
-    
+
 class StompCLI(Cmd, ConnectionListener):
     """
-    A command line interface to the stomp.py client.  See \link stomp::internal::connect::Connection \endlink
+    A command line interface to the stomp.py client.  See \link stomp::connect::StompConnection11 \endlink
     for more information on establishing a connection to a stomp server.
     """
-    def __init__(self, host='localhost', port=61613, user='', passcode='', ver=1.1, stdin=sys.stdin, stdout=sys.stdout):
+    def __init__(self, host='localhost', port=61613, user='', passcode='', ver='1.1', prompt='> ', verbose=True, stdin=sys.stdin, stdout=sys.stdout):
         Cmd.__init__(self, 'Tab', stdin, stdout)
         ConnectionListener.__init__(self)
+        self.prompt = prompt
+        self.verbose = verbose
         self.user = user
         self.passcode = passcode
-        if ver == 1.0:
+        self.__quit = False
+        if ver == '1.0':
             self.conn = StompConnection10([(host, port)], wait_on_receipt=True)
-        elif ver == 1.1:
+        elif ver == '1.1':
             self.conn = StompConnection11([(host, port)], wait_on_receipt=True)
-        elif ver == 1.2:
+        elif ver == '1.2':
             self.conn = StompConnection12([(host, port)], wait_on_receipt=True)
+        elif ver == 'multicast':
+            self.conn = MulticastConnection()
+        else:
+            raise RuntimeError('Unknown version')
         self.conn.set_listener('', self)
         self.conn.start()
         self.conn.connect(self.user, self.passcode, wait=True)
         self.transaction_id = None
         self.version = ver
+        try:
+            self.nversion = float(ver)
+        except ValueError:
+            self.nversion = 1.0
         self.__subscriptions = {}
         self.__subscription_id = 1
-        self.prompt = '> '
 
     def __print_async(self, frame_type, headers, body):
         """
@@ -57,19 +77,21 @@ class StompCLI(Cmd, ConnectionListener):
         for the next input
         """
         self.__sysout("\r  \r", end='')
-        self.__sysout(frame_type)
-        for header_key in headers.keys():
-            self.__sysout('%s: %s' % (header_key, headers[header_key]))
-        self.__sysout('')
+        if self.verbose:
+            self.__sysout(frame_type)
+            for header_key in headers.keys():
+                self.__sysout('%s: %s' % (header_key, headers[header_key]))
+        if self.prompt != '':
+            self.__sysout('')
         self.__sysout(body)
-        self.__sysout('> ', end='')
+        self.__sysout(self.prompt, end='')
         self.stdout.flush()
-        
+
     def __sysout(self, msg, end="\n"):
         self.stdout.write(str(msg) + end)
-        
+
     def __error(self, msg, end="\n"):
-        self.stdout.write(colors.BOLD + colors.RED + str(msg) + colors.NO_COLOR + end)
+        self.stdout.write(stomp.colors.BOLD + stomp.colors.RED + str(msg) + stomp.colors.NO_COLOR + end)
 
     def on_connecting(self, host_and_port):
         """
@@ -80,12 +102,13 @@ class StompCLI(Cmd, ConnectionListener):
         """
         \see ConnectionListener::on_disconnected
         """
-        self.__error("lost connection")
+        if not self.__quit:
+            self.__error("lost connection")
 
     def on_message(self, headers, body):
         """
         \see ConnectionListener::on_message
-        
+
         Special case: if the header 'filename' is present, the content is written out
         as a file
         """
@@ -119,81 +142,82 @@ class StompCLI(Cmd, ConnectionListener):
         \see ConnectionListener::on_connected
         """
         self.__print_async("CONNECTED", headers, body)
-        
+
     def help_help(self):
         self.__sysout('Quick help on commands')
-        
+
     def default(self, line):
         self.__error('Unknown command: %s' % line.split()[0])
-        
+
     def emptyline(self):
         pass
-        
-    def help(self, usage, description, required = [], optional = []):        
+
+    def help(self, usage, description, required=[], optional=[]):
         required.insert(0, '')
         rparams = "\n\t".join(required)
-        
+
         optional.insert(0, '')
         oparams = "\n\t".join(optional)
-        
+
         m = {
-            'hl' : colors.BOLD + colors.GREEN,
-            'nc' : colors.NO_COLOR,
+            'hl' : stomp.colors.BOLD + stomp.colors.GREEN,
+            'nc' : stomp.colors.NO_COLOR,
             'usage' : usage,
             'description' : description,
             'required' : rparams.rstrip(),
             'optional' : oparams.rstrip()
         }
-        
+
         if rparams.rstrip() != '':
             rparams = '''%(hl)sRequired Parameters:%(nc)s%(required)s\n\n''' % m
             m['required'] = rparams
-            
+
         if oparams.rstrip() != '':
             oparams = '''%(hl)sOptional Parameters:%(nc)s%(optional)s\n\n''' % m
             m['optional'] = oparams
-        
+
         self.__sysout('''%(hl)sUsage:%(nc)s
 \t%(usage)s
 
 %(required)s%(optional)s%(hl)sDescription:%(nc)s
 \t%(description)s
         ''' % m)
-     
+
     def do_quit(self, args):
+        self.__quit = True
         return True
     do_exit = do_quit
     do_EOF = do_quit
-    
+
     def help_quit(self):
         self.help('exit', 'Exit the stomp client')
     help_exit = help_quit
-    
+
     def help_EOF(self):
         self.__sysout('')
-        
+
     def do_subscribe(self, args):
         args = args.split()
         if len(args) < 1:
             self.__error('Expecting: subscribe <destination> [ack]')
             return
-        
+
         name = args[0]
         if name in self.__subscriptions:
             self.__error('Already subscribed to %s' % name)
             return
-        
+
         ack_mode = 'auto'
         if len(args) >= 2:
-            ack_mode = args[1]   
-        
+            ack_mode = args[1]
+
         sid = self.__subscription_id
         self.__subscription_id += 1
 
         self.__sysout('Subscribing to "%s" with acknowledge set to "%s", id set to "%s"' % (name, ack_mode, sid))
-        self.conn.subscribe(destination=name, ack=ack_mode, id=sid)            
+        self.conn.subscribe(destination=name, ack=ack_mode, id=sid)
         self.__subscriptions[name] = SubscriptionInfo(sid, ack_mode)
-            
+
     def help_subscribe(self):
         self.help('subscribe <destination> [ack]',
             '''Register to listen to a given destination. Like send, the subscribe command requires a destination
@@ -205,11 +229,11 @@ class StompCLI(Cmd, ConnectionListener):
         if len(args) < 1:
             self.__error('Expecting: unsubscribe <destination>')
             return
-    
+
         if args[0] not in self.__subscriptions.keys():
             self.__sysout('Subscription %s not found' % args[0])
             return
-        
+
         self.__sysout('Unsubscribing from "%s"' % args[0])
         self.conn.unsubscribe(destination=args[0], id=self.__subscriptions[args[0]].id)
         del self.__subscriptions[args[0]]
@@ -226,16 +250,16 @@ class StompCLI(Cmd, ConnectionListener):
             self.conn.send(args[0], ' '.join(args[1:]))
         else:
             self.conn.send(args[0], ' '.join(args[1:]), transaction=self.transaction_id)
-            
+
     def complete_send(self, text, line, begidx, endidx):
-        mline = line.split(' ')[1] 
-        offs = len(mline) - len(text) 
+        mline = line.split(' ')[1]
+        offs = len(mline) - len(text)
         return [s[offs:] for s in self.__subscriptions if s.startswith(mline)]
     complete_unsubscribe = complete_send
     complete_sendrec = complete_send
     complete_sendreply = complete_send
     complete_sendfile = complete_send
-            
+
     def help_send(self):
         self.help('send <destination> <message>', 'Sends a message to a destination in the messaging system.',
             [ 'destination - where to send the message', 'message - the content to send' ])
@@ -253,7 +277,7 @@ class StompCLI(Cmd, ConnectionListener):
     def help_sendrec(self):
         self.help('sendrec <destination> <message>', 'Sends a message to a destination in the messaging system and blocks for receipt of the message.',
                     [ 'destination - where to send the message', 'message - the content to send' ])
-                    
+
     def do_sendreply(self, args):
         args = args.split()
         if len(args) < 3:
@@ -284,59 +308,59 @@ class StompCLI(Cmd, ConnectionListener):
                 [ 'destination - where to send the message', 'filename - the file to send' ])
 
     def do_version(self, args):
-        self.__sysout('%s%s [Protocol version %s]%s' % (colors.BOLD, stomppy_version, self.conn.version, colors.NO_COLOR))
+        self.__sysout('%s%s [Protocol version %s]%s' % (stomp.colors.BOLD, stomppy_version, self.conn.version, stomp.colors.NO_COLOR))
     do_ver = do_version
-    
+
     def help_version(self):
         self.help('version', 'Display the version of the client')
     help_ver = help_version
-    
+
     def check_ack_nack(self, cmd, args):
-        if self.version >= 1.1 and len(args) < 2:
+        if self.nversion >= 1.2 and len(args) < 1:
+            self.__error("Expecting: %s <ack-id>" % cmd)
+            return None
+        elif self.nversion == 1.1 and len(args) < 2:
             self.__error("Expecting: %s <message-id> <subscription-id>" % cmd)
             return None
         elif len(args) < 1:
             self.__error("Expecting: %s <message-id>" % cmd)
             return None
-            
-        hdrs = { 'message-id' : args[0] }
-            
-        if self.version >= 1.1:
-            if len(args) < 2:
-                self.__error("Expecting: %s <message-id> <subscription-id>" % cmd)
-                return
-            hdrs['subscription'] = args[1]
-            
-        return hdrs
-    
+
+        if len(args) == 1:
+            return (args[0], None)
+        else:
+            return (args[0], args[1])
+
     def do_ack(self, args):
         args = args.split()
         hdrs = self.check_ack_nack('ack', args)
         if hdrs is None:
             return
-            
+
+        (message_id, subscription_id) = hdrs
+
         if not self.transaction_id:
-            self.conn.ack(headers = hdrs)
+            self.conn.ack(message_id, subscription_id)
         else:
-            self.conn.ack(headers = hdrs, transaction=self.transaction_id)
-            
+            self.conn.ack(message_id, subscription_id, transaction=self.transaction_id)
+
     def help_ack(self):
         self.help('ack <message-id> [subscription-id]', '''The command 'ack' is used to acknowledge consumption of a message from a subscription using client
 \tacknowledgment. When a client has issued a 'subscribe' with the ack flag set to client, any messages
 \treceived from that destination will not be considered to have been consumed (by the server) until
 \tthe message has been acknowledged.''', [ 'message-id - the id of the message being acknowledged' ], [ 'subscription-id the id of the subscription (only required for STOMP 1.1)' ] )
-            
+
     def do_nack(self, args):
         args = args.split()
         hdrs = self.check_ack_nack('nack', args)
         if hdrs is None:
             return
-            
+
         if not self.transaction_id:
             self.conn.nack(headers = hdrs)
         else:
             self.conn.nack(headers = hdrs, transaction=self.transaction_id)
-    
+
     def help_nack(self):
         self.help('nack <message-id> [subscription]', '''The command 'nack' is used to acknowledge the failure of a message from a subscription using client
 \tacknowledgment. When a client has issued a 'subscribe' with the ack flag set to client, any messages
@@ -362,7 +386,7 @@ class StompCLI(Cmd, ConnectionListener):
         else:
             self.transaction_id = self.conn.begin()
             self.__sysout('Transaction id: %s' % self.transaction_id)
-            
+
     def help_begin(self):
         self.help('begin', '''Start a transaction. Transactions in this case apply to sending and acknowledging -
 \tany messages sent or acknowledged during a transaction will be handled atomically based on the
@@ -375,7 +399,7 @@ class StompCLI(Cmd, ConnectionListener):
             self.__sysout('Committing %s' % self.transaction_id)
             self.conn.commit(transaction=self.transaction_id)
             self.transaction_id = None
-            
+
     def help_commit(self):
         self.help('commit', 'Commit a transaction in progress.')
 
@@ -393,7 +417,7 @@ class StompCLI(Cmd, ConnectionListener):
             self.conn.remove_listener('stats')
         else:
             self.__error('Expecting: stats [on|off]')
-            
+
     def help_stats(self):
         self.help('stats [on|off]', '''Record statistics on messages sent, received, errors, etc. If no argument (on|off) is specified,
 \tdump the current statistics.''')
@@ -412,10 +436,13 @@ class StompCLI(Cmd, ConnectionListener):
     def help_run(self):
         self.help('run <filename>', 'Execute commands in a specified file')
 
+def do_nothing_loop():
+    while 1:
+        time.sleep(1)
 
-def main():    
+def main():
     parser = OptionParser(version=stomppy_version)
-    
+
     parser.add_option('-H', '--host', type = 'string', dest = 'host', default = 'localhost',
                       help = 'Hostname or IP to connect to. Defaults to localhost if not specified.')
     parser.add_option('-P', '--port', type = int, dest = 'port', default = 61613,
@@ -426,15 +453,36 @@ def main():
                       help = 'Password for the connection')
     parser.add_option('-F', '--file', type = 'string', dest = 'filename',
                       help = 'File containing commands to be executed, instead of prompting from the command prompt.')
-    parser.add_option('-S', '--stomp', type = 'float', dest = 'stomp', default = 1.1,
+    parser.add_option('-S', '--stomp', type = 'string', dest = 'stomp', default = '1.1',
                       help = 'Set the STOMP protocol version.')
-                      
+    parser.add_option('-L', '--listen', type = 'string', dest = 'listen', default = None,
+                      help = 'Listen for messages on a queue/destination')
+    parser.add_option("-V", "--verbose", dest = "verbose", default = 'on',
+                      help = 'Verbose logging "on" or "off" (if on, full headers from stomp server responses are printed)')
+
     parser.set_defaults()
     (options, args) = parser.parse_args()
-    
-    st = StompCLI(options.host, options.port, options.user, options.password, options.stomp)
-    
-    if options.filename:
+
+    if options.verbose == 'on':
+        verbose = True
+    else:
+        verbose = False
+
+    if options.listen:
+        prompt = ''
+    else:
+        prompt = '> '
+
+    st = StompCLI(options.host, options.port, options.user, options.password, options.stomp, prompt, verbose)
+
+    if options.listen:
+        st.do_subscribe(options.listen)
+        try:
+            while 1:
+                time.sleep(10)
+        except:
+            print("\n")
+    elif options.filename:
         st.do_run(options.filename)
     else:
         try:
@@ -451,4 +499,3 @@ def main():
 #
 if __name__ == '__main__':
     main()
-
