@@ -3,39 +3,39 @@
 import time
 import unittest
 
-import base64
-
 import stomp
 
-from testutils import *
+from stomp.test.testutils import *
 
 class TestNonAsciiSend(unittest.TestCase):
 
     def setUp(self):
         conn = stomp.Connection(get_standard_host())
-        listener = TestListener()
+        listener = TestListener('123')
         conn.set_listener('', listener)
         conn.start()
         conn.connect('admin', 'password', wait=True)
         self.conn = conn
         self.listener = listener
-        
+        self.timestamp = time.strftime('%Y%m%d%H%M%S')
+
     def tearDown(self):
         if self.conn:
-            self.conn.disconnect()
-       
+            self.conn.disconnect(receipt=None)
+
     def test_send_nonascii(self):
-        self.conn.subscribe(destination='/queue/test', ack='auto', id="1")
+        queuename = '/queue/p2nonasciitest-%s' % self.timestamp
+        self.conn.subscribe(destination=queuename, ack='auto', id="1")
 
         txt = u'марко'
-        self.conn.send(body=txt, destination='/queue/test')
+        self.conn.send(body=txt, destination=queuename, receipt='123')
 
-        time.sleep(3)
+        self.listener.wait_on_receipt()
 
         self.assert_(self.listener.connections == 1, 'should have received 1 connection acknowledgement')
         self.assert_(self.listener.messages == 1, 'should have received 1 message')
         self.assert_(self.listener.errors == 0, 'should not have received any errors')
 
-        msg = self.listener.message_list[0]
-        self.assertEquals(txt, msg.decode('utf-8'))
-        
+        (headers, msg) = self.listener.get_latest_message()
+        self.assertEquals(stomp.backward.encode(txt), msg)
+
