@@ -1,9 +1,8 @@
-import time
 import unittest
 
 import stomp
 
-from testutils import *
+from stomp.test.testutils import *
 
 class TestRabbitMQSend(unittest.TestCase):
 
@@ -12,22 +11,20 @@ class TestRabbitMQSend(unittest.TestCase):
 
     def testbasic(self):
         conn = stomp.Connection10(get_stompserver_host())
-        listener = TestListener()
+        listener = TestListener('123')
         conn.set_listener('', listener)
         conn.start()
         conn.connect(wait=True)
         conn.subscribe(destination='/queue/test', ack='auto')
 
-        conn.send(body='this is a test', destination='/queue/test')
+        conn.send(body='this is a test', destination='/queue/test', receipt='123')
+
+        listener.wait_on_receipt()
 
-        time.sleep(2)
-        
         conn.unsubscribe('/queue/test')
-        
-        conn.disconnect()
+
+        conn.disconnect(receipt=None)
 
         self.assert_(listener.connections == 1, 'should have received 1 connection acknowledgement')
         self.assert_(listener.messages == 1, 'should have received 1 message')
         self.assert_(listener.errors == 0, 'should not have received any errors')
-
-
